@@ -17,6 +17,7 @@
 """Command line
 """
 import re
+import os
 from datetime import datetime
 import json
 import logging
@@ -43,17 +44,19 @@ def connect_qix_engine(host, certfile, keyfile, ca_certs, user_directory, user_i
 class Qsense:
     """qsense is a python library and command line tool for Qliksense administrators"""
 
-    def get(self, host, certificate, path, pFilter="1 eq 1", service="qrs", port=4242):
+    def get(self, host, certificate, path, pFilter=None, service="qrs", port=4242):
         """generic get http from Qlik (service can be qrs or qps)"""
         if service.upper() == "QPS":
             qrs = qsAPI.QPS(proxy=host, certificate=certificate, port=port)
         else:
             qrs = qsAPI.QRS(proxy=host, certificate=certificate, port=port)
-        param = {"filter": pFilter}
+        param = {"filter": pFilter} if pFilter else None
+
         resp = qrs.driver.get(path, param=param)
         if resp.ok:
             return json.dumps(resp.json())
         else:
+            logging.error(resp)
             return resp
 
     def post(
@@ -66,7 +69,7 @@ class Qsense:
         body=None,
         filename=None,
     ):
-        """NOT TESTED: generic post http to Qlik (service can be qrs or qps)"""
+        """generic post http request to Qlik (service can be qrs or qps)"""
         logging.debug("Body= {body}".format(body=body))
         if service.upper() == "QPS":
             qrs = qsAPI.QPS(proxy=host, certificat=certificate, port=port)
@@ -88,6 +91,39 @@ class Qsense:
         else:
             return resp
 
+    def put(
+        self,
+        host,
+        certificate,
+        path,
+        service="qrs",
+        port=4242,
+        body=None,
+        filename=None,
+    ):
+        """generic put http request to Qlik (service can be qrs or qps)"""
+        logging.debug("Body= {body}".format(body=body))
+        if service.upper() == "QPS":
+            qrs = qsAPI.QPS(proxy=host, certificat=certificate, port=port)
+        else:
+            qrs = qsAPI.QRS(proxy=host, certificate=certificate, port=port)
+
+        data = "{}"
+
+        if filename:
+            with open(filename, "r") as myfile:
+                data = myfile.read()  # .replace("\n", "")
+        elif body:
+            data = body
+        logging.debug(data)
+        resp = qrs.driver.put(path, data=data)
+        logging.debug(resp)
+
+    # if resp.ok:
+    #     return json.dumps(resp.json())
+    # else:
+    #     return resp
+
     def user_sessions(
         self, host, certificate, userdirectory, userid, virtualproxy="", port=4243
     ):
@@ -104,6 +140,7 @@ class Qsense:
         if resp.ok:
             return json.dumps(resp.json())
         else:
+            logging.error(resp)
             return resp
 
     def delete_user_session(
@@ -167,7 +204,7 @@ class Qsense:
                     del body["id"]
             logging.debug(f"Adding entity {entity}")
             logging.debug(body)
-            result = qrs.driver.post(f"/qrs/{entity}")
+            result = qrs.driver.post(f"/qrs/{entity}", data=body)
             logging.debug(result)
             # logging.debug(result.json())
 
@@ -187,10 +224,10 @@ class Qsense:
             id = body["id"]
             logging.debug(f"Updating resource {entity} with id {id}")
             logging.debug(body)
-            result = qrs.driver.put(f"/qrs/{entity}/{id}")
+            result = qrs.driver.put(f"/qrs/{entity}/{id}", data=body)
             logging.debug(result)
-            out = result.json()
-
+            # out = result.ok
+            out = result  # .json()
             logging.debug(out)
 
     def entity(self, host, certificate, entity, id="full", filter=None):
@@ -260,6 +297,17 @@ class Qsense:
         qrs = qsAPI.QRS(proxy=host, certificate=certificate)
         return qsense.users.user_info(qrs, user_id, resources, access)
 
+    ## ["0: NeverStarted", "1: Triggered", "2: Started", "3: Queued", "4: AbortInitiated", "5: Aborting", "6: Aborted", "7: FinishedSuccess", "8: FinishedFail", "9: Skipped", "10: Retry", "11: Error", "12: Reset"]
+    def reloadtask_count(self, host, certificate, status):
+        """Reloadtask count. Status 2=Started, 3=Queued, 7=FinishSuccessfully"""
+        qrs = qsAPI.QRS(proxy=host, certificate=certificate)
+        return qsense.reloadtask.reloadtask_count(qrs, status)
+
+    def reloadtask_status(self, host, certificate, task_id, max_age):
+        """Reloadtask status. Max_age is in seconds"""
+        qrs = qsAPI.QRS(proxy=host, certificate=certificate)
+        return qsense.reloadtask.reloadtask_status(qrs, task_id, max_age)
+
     def old_apps(
         self,
         host,
@@ -267,6 +315,7 @@ class Qsense:
         modified_days=1000,
         last_reload_days=1000,
         published=False,
+        pFilter="1 eq 1",
         target_path=".",
         save_meta=True,
         skipdata=True,
@@ -274,13 +323,14 @@ class Qsense:
         delete=False,
     ):
         """Find old apps using 'modified_date' and 'last_reload_time' filters:
-        then you can export them or delete or notify via email the owners"""
+        then you can export them or delete"""
         qrs = qsAPI.QRS(proxy=host, certificate=certificate)
         return qsense.apps.find_old_apps(
             qrs,
             modified_days,
             last_reload_days,
             published=published,
+            pFilter=pFilter,
             target_path=target_path,
             save_meta=save_meta,
             skipdata=skipdata,
@@ -376,7 +426,7 @@ class Qsense:
 
 def main():
     """main"""
-    logging.basicConfig(level=logging.DEBUG)
+    logging.basicConfig(level=os.environ.get("LOGLEVEL", "INFO"))
     fire.Fire(Qsense)
 
 
